#[non_exhaustive]pub enum ClientCode {
Show 13 variants
BU,
EJ,
EG,
GE,
GR,
LH,
LS,
NM,
NB,
TE,
TK,
PM,
RH,
}Expand description
This enum defines a standard for specifying a client with just two letters. Clients teams which have a code reserved in this list MUST use this code when identifying themselves.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BU
Besu
EJ
EthereumJS
EG
Erigon
GE
Geth, go-ethereum
GR
Grandine
LH
Lighthouse
LS
Lodestar
NM
Nethermind
NB
Nimbus
TE
Trin Execution
TK
Teku
PM
Prysm
RH
Reth
Implementations
Sourceimpl ClientCode
impl ClientCode