ExecutionData

Struct ExecutionData 

pub struct ExecutionData {
    pub payload: ExecutionPayload,
    pub sidecar: ExecutionPayloadSidecar,
}
Struct aggregating ExecutionPayload and ExecutionPayloadSidecar and encapsulating complete payload supplied for execution.

Fields

payload: ExecutionPayload

Execution payload.

sidecar: ExecutionPayloadSidecar

Additional fork-specific fields.

Implementations

Source

impl ExecutionData

pub const fn new( payload: ExecutionPayload, sidecar: ExecutionPayloadSidecar, ) -> Self

Creates new instance of ExecutionData.

pub fn from_block_unchecked<T, H>(block_hash: B256, block: &Block<T, H>) -> Self

Conversion from alloy_consensus::Block. Also returns the ExecutionPayloadSidecar extracted from the block.

For the ExecutionPayloadSidecar this is expected to use just the requests hash, because the Requests are not part of the block/header. See also RequestsOrHash. Likewise, Amsterdam/V4 payload conversion falls back to the header’s block_access_list_hash bytes when the full RLP-encoded block access list is not available on the block value, or to the canonical empty BAL hash bytes if the header does not carry a BAL hash.

See also ExecutionPayload::from_block_unchecked.

pub const fn parent_hash(&self) -> B256

Returns the parent hash of the block.

pub const fn block_hash(&self) -> B256

Returns the hash of the block.

pub const fn block_number(&self) -> u64

Returns the number of the block.

pub fn parent_beacon_block_root(&self) -> Option<B256>

Returns the parent beacon block root, if any.

pub const fn withdrawals(&self) -> Option<&Vec<Withdrawal>>

Return the withdrawals for the payload or attributes.

pub const fn transaction_count(&self) -> usize

Returns the number of transactions in the payload.

pub fn try_into_block<T: Decodable2718>(self) -> Result<Block<T>, PayloadError>

Tries to create a new unsealed block from the given payload and payload sidecar.

Performs additional validation of extra_data and base_fee_per_gas fields. The payload’s advertised block_hash is not recomputed or compared.

Note

The log bloom is assumed to be validated during serialization.

See https://github.com/ethereum/go-ethereum/blob/79a478bb6176425c2400e949890e668a3d9a3d05/core/beacon/types.go#L145

pub fn try_into_block_with<T, F, E>( self, f: F, ) -> Result<Block<T>, PayloadError>
where F: FnMut(Bytes) -> Result<T, E>, E: Into<PayloadError>,

Tries to create a new unsealed block from the given payload and payload sidecar with a custom transaction mapper.

Performs additional validation of extra_data and base_fee_per_gas fields.

Note

The log bloom is assumed to be validated during serialization.

See https://github.com/ethereum/go-ethereum/blob/79a478bb6176425c2400e949890e668a3d9a3d05/core/beacon/types.go#L145

pub fn into_block_raw(self) -> Result<Block<Bytes>, PayloadError>

Converts ExecutionData to Block with raw Bytes transactions.

This is similar to Self::try_into_block_with but returns the transactions as raw bytes without any conversion.