ExecutionPayloadBodyV2

Struct ExecutionPayloadBodyV2 

pub struct ExecutionPayloadBodyV2 {
    pub transactions: Vec<Bytes>,
    pub withdrawals: Option<Vec<Withdrawal>>,
    pub block_access_list: Option<Bytes>,
}
This structure contains a body of an execution payload (V2).

V2 extends V1 with the blockAccessList field introduced in EIP-7928.

See also: https://eips.ethereum.org/EIPS/eip-7928

Fields

transactions: Vec<Bytes>

Enveloped encoded transactions.

withdrawals: Option<Vec<Withdrawal>>

All withdrawals in the block.

Will always be None if pre shanghai.

block_access_list: Option<Bytes>

The RLP-encoded block access list.

Will be None for pre-Amsterdam blocks or when data has been pruned.

Implementations

Source

impl ExecutionPayloadBodyV2

pub fn new<'a, T>( withdrawals: Option<Withdrawals>, transactions: impl IntoIterator<Item = &'a T>, block_access_list: Option<Bytes>, ) -> Self
where T: Encodable2718 + 'a,

Creates an ExecutionPayloadBodyV2 from the given withdrawals, transactions, and block access list.

pub fn from_block<T: Encodable2718, H>( block: Block<T, H>, block_access_list: Option<Bytes>, ) -> Self

Converts a alloy_consensus::Block into an execution payload body, with an optional block access list.