pub struct PayloadAttributes {
pub timestamp: u64,
pub prev_randao: B256,
pub suggested_fee_recipient: Address,
pub withdrawals: Option<Vec<Withdrawal>>,
pub parent_beacon_block_root: Option<B256>,
pub slot_number: Option<u64>,
}Expand description
This structure contains the attributes required to initiate a payload build process in the
context of an engine_forkchoiceUpdated call.
Fields
timestamp: u64Value for the timestamp field of the new payload
prev_randao: B256Value for the prevRandao field of the new payload
suggested_fee_recipient: AddressSuggested value for the feeRecipient field of the new payload
withdrawals: Option<Vec<Withdrawal>>Array of Withdrawal enabled with V2
See https://github.com/ethereum/execution-apis/blob/6452a6b194d7db269bf1dbd087a267251d3cc7f8/src/engine/shanghai.md#payloadattributesv2
parent_beacon_block_root: Option<B256>Root of the parent beacon block enabled with V3.
See also https://github.com/ethereum/execution-apis/blob/main/src/engine/cancun.md#payloadattributesv3
slot_number: Option<u64>Slot of the current block enabled with Amsterdam fork.
Implementations
Sourceimpl PayloadAttributes
impl PayloadAttributes
Sourcepub const fn with_timestamp(self, timestamp: u64) -> Self
pub const fn with_timestamp(self, timestamp: u64) -> Self
Sets the timestamp for the payload attributes.
Sourcepub fn with_withdrawals(self, withdrawals: Vec<Withdrawal>) -> Self
pub fn with_withdrawals(self, withdrawals: Vec<Withdrawal>) -> Self
Sets the withdrawals for the payload attributes.
Sourcepub const fn with_parent_beacon_block_root(
self,
parent_beacon_block_root: B256,
) -> Self
pub const fn with_parent_beacon_block_root( self, parent_beacon_block_root: B256, ) -> Self
Sets the parent beacon block root for the payload attributes.
Sourcepub const fn with_slot_number(self, slot_number: u64) -> Self
pub const fn with_slot_number(self, slot_number: u64) -> Self
Sets the slot number for the payload attributes.