PayloadError

Enum PayloadError 

pub enum PayloadError {
Show 20 variants ExtraData(Bytes), BaseFee(U256), BlobGasUsed(U256), ExcessBlobGas(U256), PreShanghaiBlockWithWithdrawals, PostShanghaiBlockWithoutWithdrawals, PreCancunBlockWithParentBeaconBlockRoot, PreCancunBlockWithBlobTransactions, PreCancunBlockWithBlobGasUsed, PreCancunBlockWithExcessBlobGas, PreCancunWithCancunFields, PostCancunBlockWithoutParentBeaconBlockRoot, PostCancunBlockWithoutBlobGasUsed, PostCancunBlockWithoutExcessBlobGas, PostCancunWithoutCancunFields, PrePragueBlockWithEip7702Transactions, PrePragueBlockRequests, BlockHash { execution: B256, consensus: B256, }, InvalidVersionedHashes, Decode(Error),
}
Error that can occur when handling payloads.

Variants



ExtraData(Bytes)

Invalid payload extra data.



BaseFee(U256)

Invalid payload base fee.



BlobGasUsed(U256)

Invalid payload blob gas used.



ExcessBlobGas(U256)

Invalid payload excess blob gas.



PreShanghaiBlockWithWithdrawals

withdrawals present in pre-shanghai payload.



PostShanghaiBlockWithoutWithdrawals

withdrawals missing in post-shanghai payload.



PreCancunBlockWithParentBeaconBlockRoot

parent beacon block root present in pre-cancun payload.



PreCancunBlockWithBlobTransactions

blob transactions present in pre-cancun payload.



PreCancunBlockWithBlobGasUsed

blob gas used present in pre-cancun payload.



PreCancunBlockWithExcessBlobGas

excess blob gas present in pre-cancun payload.



PreCancunWithCancunFields

cancun fields present in pre-cancun payload.



PostCancunBlockWithoutParentBeaconBlockRoot

parent beacon block root missing in post-cancun payload.



PostCancunBlockWithoutBlobGasUsed

blob gas used missing in post-cancun payload.



PostCancunBlockWithoutExcessBlobGas

excess blob gas missing in post-cancun payload.



PostCancunWithoutCancunFields

cancun fields missing in post-cancun payload.



PrePragueBlockWithEip7702Transactions

EIP-7702 transactions present in pre-prague payload.



PrePragueBlockRequests

requests present in pre-prague payload.



BlockHash

Invalid payload block hash.

Fields

execution: B256

The block hash computed from the payload.

consensus: B256

The block hash provided with the payload.



InvalidVersionedHashes

Expected blob versioned hashes do not match the given transactions.



Decode(Error)

Encountered decoding error.

Implementations

Source

impl PayloadError

pub const fn is_block_hash_mismatch(&self) -> bool

Returns true if the error is caused by a block hash mismatch.

pub const fn is_invalid_versioned_hashes(&self) -> bool

Returns true if the error is caused by invalid block hashes (Cancun).